==> img0ch-2.1.17.tar.bz2: img0ch/_template/zeromin2/plugin_switch_load.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/plugin_right_menu.cs" ?>

<div id="main">

<form id="pluginContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">プラグイン管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=switch_load&amp;id=<?cs var:html_escape(PluginId) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(PluginClassName) ?>::<?cs var:html_escape(PluginMethodName) ?>の有効無効設定</a>
</div>

<h1><?cs var:html_escape(PluginClassName) ?>::<?cs var:html_escape(PluginMethodName) ?>の有効無効設定</h1>

<?cs if:Code0 ?>
<?cs if:Done_plugin_switch_save ?><div class="noticeSuccess" id="notify"><p>プラグインの有効及び無効の情報を更新しました</p></div><?cs /if ?>
<?cs if:Done_plugin_switch_load ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
 <label for="bbs" title="bbs">プラグインの有効状況</label>
 <input type="radio" name="all" value="1"<?cs if:IsGlobal ?> checked="checked"<?cs /if ?>/>全ての掲示板で有効にする<br />
 <input type="radio" name="all" value="0"<?cs if:!IsGlobal ?> checked="checked"<?cs /if ?>/>以下の掲示板で有効にする<br />
 <select id="bbs" name="bbs" title="bbs" multiple="multiple" size="5">
  <?cs each:item = BBSList ?><option value="<?cs var:html_escape(item.id) ?>"<?cs if:item.selected ?> selected="selected"<?cs /if ?>><?cs var:item.name ?></option>
  <?cs /each ?>
 </select>
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="plugin" />
<input type="hidden" name="method" value="switch_save" />
<input type="hidden" name="id" value="<?cs var:html_escape(PluginId) ?>" />
<input type="hidden" name="OK" value="switch_load" />
<input type="hidden" name="NG" value="switch_load" />
<input type="submit" value="更新" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.1.4.tar.bz2: img0ch/_template/zeromin2/plugin_switch_load.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu.cs" ?>

<?cs include:"zeromin2/plugin_right_menu.cs" ?>

<div id="main">

<form id="pluginContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">プラグイン管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=plugin&amp;method=switch_load&amp;id=<?cs var:html_escape(PluginId) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(PluginClassName) ?>::<?cs var:html_escape(PluginMethodName) ?>の有効無効設定</a>
</div>

<h1><?cs var:html_escape(PluginClassName) ?>::<?cs var:html_escape(PluginMethodName) ?>の有効無効設定</h1>

<?cs if:Code0 ?>
<?cs if:Done_plugin_switch_save ?><div class="noticeSuccess" id="notify"><p>プラグインの有効及び無効の情報を更新しました</p></div><?cs /if ?>
<?cs if:Done_plugin_switch_load ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>

<p>
 <label for="bbs" title="bbs">プラグインの有効状況</label>
 <label for="enable_all"><input id="enable_all" type="radio" name="all" value="1"<?cs if:IsGlobal ?> checked="checked"<?cs /if ?>/>全ての掲示板で有効にする</label>
 <label for="enable_spec"><input id="enable_spec" type="radio" name="all" value="0"<?cs if:!IsGlobal ?> checked="checked"<?cs /if ?>/>以下の掲示板で有効にする</label>
 <select id="bbs" name="bbs" title="bbs" multiple="multiple" size="5">
  <?cs each:item = BBSList ?><option value="<?cs var:html_escape(item.id) ?>"<?cs if:item.selected ?> selected="selected"<?cs /if ?>><?cs var:item.name ?></option>
  <?cs /each ?>
 </select>
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="plugin" />
<input type="hidden" name="method" value="switch_save" />
<input type="hidden" name="id" value="<?cs var:html_escape(PluginId) ?>" />
<input type="hidden" name="OK" value="switch_load" />
<input type="hidden" name="NG" value="switch_load" />
<input type="submit" value="更新" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
